[java-opensaml] branch main updated: OSJ-318 - Deprecate terms from classes and configuration

Scott Cantor cantor.2 at osu.edu
Tue Nov 24 17:03:41 UTC 2020


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch main
in repository java-opensaml.

View the commit online:
http://git.shibboleth.net/view/?p=java-opensaml.git;a=commit;h=73b463805eab9a5ea4d2668ef167424de0134795

The following commit(s) were added to refs/heads/main by this push:
       new  73b463805 OSJ-318 - Deprecate terms from classes and configuration
73b463805 is described below

commit 73b463805eab9a5ea4d2668ef167424de0134795
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Tue Nov 24 12:03:38 2020 -0500

    OSJ-318 - Deprecate terms from classes and configuration
    
    https://issues.shibboleth.net/jira/browse/OSJ-318
    
    Deprecate and replace a protected method.
---
 .../impl/BasicEncryptionParametersResolver.java    | 22 ++++++++++++++++++----
 1 file changed, 18 insertions(+), 4 deletions(-)

diff --git a/opensaml-xmlsec-impl/src/main/java/org/opensaml/xmlsec/impl/BasicEncryptionParametersResolver.java b/opensaml-xmlsec-impl/src/main/java/org/opensaml/xmlsec/impl/BasicEncryptionParametersResolver.java
index 34e7479af..5d9a47dc9 100644
--- a/opensaml-xmlsec-impl/src/main/java/org/opensaml/xmlsec/impl/BasicEncryptionParametersResolver.java
+++ b/opensaml-xmlsec-impl/src/main/java/org/opensaml/xmlsec/impl/BasicEncryptionParametersResolver.java
@@ -271,18 +271,32 @@ public class BasicEncryptionParametersResolver extends AbstractSecurityParameter
         return true;
     }
 // Checkstyle: CyclomaticComplexity ON
-    
+
     /**
      * Get a predicate which implements the effective configured whitelist/blacklist policy.
      * 
      * @param criteria the input criteria being evaluated
      * 
-     * @return a whitelist/blacklist predicate instance
+     * @return a include/exclude predicate instance
      */
-    @Nonnull protected Predicate<String> getWhitelistBlacklistPredicate(@Nonnull final CriteriaSet criteria) {
+    @Nonnull protected Predicate<String> getIncludeExcludePredicate(@Nonnull final CriteriaSet criteria) {
         return resolveIncludeExcludePredicate(criteria, 
                 criteria.get(EncryptionConfigurationCriterion.class).getConfigurations());
     }
+
+    /**
+     * Get a predicate which implements the effective configured include/exclude policy.
+     * 
+     * @param criteria the input criteria being evaluated
+     * 
+     * @return a include/exclude predicate instance
+     * 
+     * @deprecated
+     */
+    @Deprecated(since="4.1.0",forRemoval=true)
+    @Nonnull protected Predicate<String> getWhitelistBlacklistPredicate(@Nonnull final CriteriaSet criteria) {
+        return getIncludeExcludePredicate(criteria);
+    }
     
     /**
      * Resolve and populate the data encryption and key transport credentials and algorithm URIs.
@@ -271,18 +271,32 @@ public class BasicEncryptionParametersResolver extends AbstractSecurityParameter
     /**
-     * Get a predicate which implements the effective configured whitelist/blacklist policy.
+     * Get a predicate which implements the effective configured include/exclude policy.
      * 
      * @param criteria the input criteria being evaluated

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list